# Bluebelt
Tools for HR Analytics

Copyright (C) 2020 Arvid Hahné

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

### What is Bluebelt?
Bluebelt is a collection of python tools that can be used in HR analytics projects. The package is far from complete but it is in active development.

### How does it work?
The package is highly dependent on Pandas. There a two ways to use the functions available.

... to be continued ...